@@ -2,7 +2,9 @@ package Imager::Color;
 
 use Imager;
 use strict;
-use vars qw();
+use vars qw($VERSION);
+
+$VERSION = "1.010";
 
 # It's just a front end to the XS creation functions.
 
@@ -109,6 +111,8 @@ sub _get_gimp_color {
     # or set the palette parameter
     for my $attempt (@gimp_search) {
       my $work = $attempt; # don't modify the source array
+      $work =~ /\$HOME/ && !defined $ENV{HOME}
+	and next;
       $work =~ s/\$HOME/$ENV{HOME}/;
       if (-e $work) {
         $filename = $work;
@@ -137,6 +141,7 @@ sub _get_gimp_color {
 
 my @x_search = 
   (
+   '/usr/share/X11/rgb.txt', # newer Xorg X11 dists use this
    '/usr/lib/X11/rgb.txt', # seems fairly standard
    '/usr/local/lib/X11/rgb.txt', # seems possible
    '/usr/X11R6/lib/X11/rgb.txt', # probably the same as the first
@@ -144,6 +149,11 @@ my @x_search =
    '/usr/openwin/lib/X11/rgb.txt',
   );
 
+# called by the test code to check if we can test this stuff
+sub _test_x_palettes {
+  @x_search;
+}
+
 # x rgb.txt cache
 # same structure as %gimp_cache
 my %x_cache;
@@ -213,7 +223,7 @@ sub _get_x_color {
 
 # Parse color spec into an a set of 4 colors
 
-sub pspec {
+sub _pspec {
   return (@_,255) if @_ == 3 && !grep /[^\d.+eE-]/, @_;
   return (@_    ) if @_ == 4 && !grep /[^\d.+eE-]/, @_;
   if ($_[0] =~ 
@@ -325,13 +335,13 @@ sub pspec {
 
 sub new {
   shift; # get rid of class name.
-  my @arg = pspec(@_);
+  my @arg = _pspec(@_);
   return @arg ? new_internal($arg[0],$arg[1],$arg[2],$arg[3]) : ();
 }
 
 sub set {
   my $self = shift;
-  my @arg = pspec(@_);
+  my @arg = _pspec(@_);
   return @arg ? set_internal($self, $arg[0],$arg[1],$arg[2],$arg[3]) : ();
 }
 
@@ -353,6 +363,8 @@ sub equals {
   return 1;
 }
 
+sub CLONE_SKIP { 1 }
+
 1;
 
 __END__
@@ -363,6 +375,8 @@ Imager::Color - Color handling for Imager.
 
 =head1 SYNOPSIS
 
+  use Imager;
+
   $color = Imager::Color->new($red, $green, $blue);
   $color = Imager::Color->new($red, $green, $blue, $alpha);
   $color = Imager::Color->new("#C0C0FF"); # html color specification
@@ -387,6 +401,29 @@ This module handles creating color objects used by imager.  The idea is
 that in the future this module will be able to handle colorspace calculations
 as well.
 
+An Imager color consists of up to four components, each in the range 0
+to 255. Unfortunately the meaning of the components can change
+depending on the type of image you're dealing with:
+
+=over
+
+=item *
+
+for 3 or 4 channel images the color components are red, green, blue,
+alpha.
+
+=item *
+
+for 1 or 2 channel images the color components are gray, alpha, with
+the other two components ignored.
+
+=back
+
+An alpha value of zero is fully transparent, an alpha value of 255 is
+fully opaque.
+
+=head1 METHODS
+
 =over 4
 
 =item new
@@ -562,7 +599,7 @@ list.
 
 =head1 SEE ALSO
 
-Imager(3)
+Imager(3), Imager::Color
 http://imager.perl.org/
 
 =cut
